# cosmograph

Python binder to the [cosmograph visual analytics tools](https://github.com/cosmograph-org) for big graphs. 

To install:	```pip install cosmograph```


# Links

* [pypi cosmograph page](https://pypi.org/project/cosmograph/)


